@@ -1,7 +1,8 @@
-# $Id$
-
 package XML::Feed::Format::RSS;
 use strict;
+use warnings;
+
+our $VERSION = '0.52';
 
 use base qw( XML::Feed );
 use DateTime::Format::Mail;
@@ -103,6 +104,14 @@ sub self_link {
     return $feed->{rss}->channel->{'atom'}{'link'};
 }
 
+# This doesn't exist in RSS
+sub first_link { };
+sub last_link { };
+sub previous_link { };
+sub next_link { };
+sub current_link { };
+sub prev_archive_link { };
+sub next_archive_link { };
 
 sub generator {
     my $feed = shift;
@@ -154,6 +163,13 @@ sub modified {
     }
 }
 
+sub image {
+    my $self = shift;
+    my $rss = $self->{rss};
+
+    return @_ ? $rss->image(@_) : $rss->image('url');
+}
+
 sub entries {
     my $rss = $_[0]->{rss};
     my @entries;
